@@ -24,7 +24,7 @@ dis = 50
 
 dataset_code = ['201']
 # dataset_code = ['205']
-site = ['37255', '4772']
+# site = ['37255', '4772']
 site = ['37255']
 
 ########################################
@@ -42,13 +42,15 @@ def test_get_dataset_codes():
 
 def test_get_Sites():
     sites1 = cf1.get_sites(dataset_code, lat, lon, dis, site_owner=True)
-    assert len(sites) > 50
+    assert len(sites1) > 15
 
 
 def test_get_ts_data():
     cf1.login('mullenkamp1', 'DWVMODJ8')
     sites2, ts1 = cf1.get_ts_data(dataset_code, site, from_date, to_date)
     cf1.logout()
+    assert len(ts1) == 10
+
 
 
 
